@@ -50,8 +50,8 @@ highlight <- function( file, output = stdout(),
 			max(data$line2) , 
 			renderer$space(), 
 			renderer$newline(), 
-			if( showPrompts) renderer$formatter( renderer$translator( prompt ) , "prompt" ) else "", 
-			if( showPrompts) renderer$formatter( renderer$translator( continue ) , "prompt" ) else "",
+			if( showPrompts) renderer$formatter( renderer$translator( prompt, size = size ) , "prompt" ) else "", 
+			if( showPrompts) renderer$formatter( renderer$translator( continue, size = size ) , "prompt" ) else "",
 			initial.spaces = initial.spaces, 
 			PACKAGE = "highlight" ), 
 		if( !is.null(renderer$footer) ) renderer$footer() )
